@@ -577,7 +577,7 @@ function(object, digits = 12, ...)
 ## e.g. trunc(times("12:13:14"), 1/(24*60))         # same
 ## e.g. trunc(times("12:13:14"), "00:01:30") # truncate to 90 seconds
 trunc.times <-
-function (x, units = "days", eps = 1e-10)
+function (x, units = "days", eps = 1e-10, ...)
 {
     if(is.character(units)) {
         idx <- pmatch(units, c("days", "hours", "minutes", "seconds"))
